import React, {
  useState,
  useEffect,
} from 'react';
import ReactDom from 'react-dom';
import { useWorldAtlas } from './useWorldAtlas';
import { useMigrantInfo } from './useMigrantInfo';
import { Marks } from './Marks';
import { scaleSqrt, max } from 'd3';

const width = 960;
const height = 500;

const App = () => {
  const worldAtlas = useWorldAtlas();
  const migrants = useMigrantInfo();

  if (!worldAtlas || !migrants) {
    return <pre>Loading...</pre>;
  }
  const sizeValue = (d) => d['Total Dead and Missing']
  const maxRadius = 12;
  const sizeScale = scaleSqrt()
    .domain([0, max(migrants, sizeValue)])
    .range([0, maxRadius]);

  return (
    <svg width={width} height={height}>
      <Marks
        worldAtlas={worldAtlas}
        migrants={migrants}
        sizeValue={sizeValue}
        sizeScale={sizeScale}

      />
    </svg>
  );
};

const rootElement = document.getElementById(
  'root'
);
ReactDOM.render(<App />, rootElement);
